@@ -7,6 +7,7 @@ import fastjsonschema
 
 from metaphor import common
 from metaphor.common.metadata_change_event import (
+    Dashboard,
     Dataset,
     EventHeader,
     Group,
@@ -35,6 +36,13 @@ class EventUtil:
         # event.event_header.time = datetime.now()  TODO: fix json validation on datetime [ch880]
         return event
 
+    @staticmethod
+    def build_dashboard_event(entity: Dashboard) -> MetadataChangeEvent:
+        """Build MCE given a dashboard"""
+        event = EventUtil._build_event()
+        event.dashboard = entity
+        return event
+
     @staticmethod
     def build_dataset_event(entity: Dataset) -> MetadataChangeEvent:
         """Build MCE given a dataset"""
