@@ -9,8 +9,7 @@ from botocore.config import Config
 from botocore.exceptions import ClientError
 from dataclasses_json import dataclass_json
 
-from metaphor.common.event_util import EventUtil
-from metaphor.common.metadata_change_event import MetadataChangeEvent
+from .sink import Sink
 
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -19,23 +18,24 @@ logger.setLevel(logging.INFO)
 @dataclass_json
 @dataclass
 class KinesisConfig:
-
     stream_name: str = "mce"
     region_name: str = "us-west-2"
     assume_role_arn: Optional[str] = None
 
+    batch_size: int = 20
     retry_mode: str = "standard"
     retry_max_attempts: int = 3
 
 
-class Kinesis:
-    """Kinesis client functions"""
+class Kinesis(Sink):
+    """Kinesis sink functions"""
 
     # TODO: Replace with proper partition key
     _partition_key = "123"
 
     def __init__(self, config: KinesisConfig):
         self._stream_name = config.stream_name
+        self._batch_size = config.batch_size
 
         session = boto3.Session()
         if config.assume_role_arn is not None:
@@ -53,15 +53,7 @@ class Kinesis:
             ),
         )
 
-    def send_messages(self, events: List[MetadataChangeEvent]) -> None:
-        """Send MCE message to Kinesis Stream"""
-        records = [EventUtil.trim_event(e) for e in events]
-        valid_records = [r for r in records if EventUtil.validate_message(r)]
-        logger.debug("Records: {}".format(json.dumps(valid_records)))
-        if valid_records:
-            self._send_records(valid_records)
-
-    def _send_records(self, messages: List) -> None:
+    def _sink(self, messages: List[dict]) -> None:
         """Send records to Kinesis Stream"""
         records = [
             {
@@ -71,14 +63,20 @@ class Kinesis:
             for msg in messages
         ]
 
-        try:
-            response = self._client.put_records(
-                StreamName=self._stream_name, Records=records
-            )
-            logger.info(f"Sent {len(messages)} records. Response {response}")
-        except ClientError:
-            logger.error("Error putting Kinesis records.")
-            raise
-        else:
-            # TODO: error handling of some records failure within batch
-            return response
+        for chunk in self._chunks(records, self._batch_size):
+            try:
+                response = self._client.put_records(
+                    StreamName=self._stream_name, Records=chunk
+                )
+            except ClientError as error:
+                logger.error(f"Error putting Kinesis records, error: {error}")
+                raise
+            else:
+                # TODO: error handling of some records failure within batch
+                logger.info(f"Sent {len(chunk)} records. Response {response}")
+
+    @staticmethod
+    def _chunks(records: List, n: int) -> List[List]:
+        """Yield successive n-sized chunks from list."""
+        for i in range(0, len(records), n):
+            yield records[i : i + n]
