@@ -106,9 +106,9 @@ class DbtExtractor(BaseExtractor):
         self, model: Dict, platform: str, datasets: Dict[str, Dict]
     ) -> None:
         dataset = self._init_dataset(model, platform)
+        self._init_schema(dataset)
 
         if "compiled_sql" in model:
-            self._init_schema(dataset)
             assert dataset.schema is not None
             dataset.schema.sql_schema = SQLSchema()
             dataset.schema.sql_schema.table_schema = model["compiled_sql"]
@@ -141,10 +141,13 @@ class DbtExtractor(BaseExtractor):
     def _parse_test(self, test: Dict) -> None:
         test_meta = test["test_metadata"]
         model_arg = test_meta["kwargs"]["model"]
-        model_name = re.findall("^{{ ref\\('([^'\" ]+)'\\) }}$", model_arg)[0]
+        matches = re.findall("^{{ ref\\('([^'\" ]+)'\\) }}$", model_arg)
+        if len(matches) == 0:
+            return
+
+        model_name = matches[0]
         table = DbtExtractor._dataset_name(test["database"], test["schema"], model_name)
         column = test_meta["kwargs"]["column_name"]
-
         dataset = self._metadata[table.upper()]
 
         field_doc = self._init_field_doc(dataset, column)
